@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2020 Tobias Fella <fella@posteo.de>
+ * SPDX-FileCopyrightText: 2020 Tobias Fella <tobias.fella@kde.org>
  * SPDX-FileCopyrightText: 2021 Bart De Vries <bart@mogwai.be>
  *
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
@@ -14,7 +14,6 @@
 #include "feed.h"
 #include "feedlogging.h"
 #include "fetcher.h"
-#include "models/entriesmodel.h"
 
 Feed::Feed(const QString &feedurl)
     : QObject(&DataManager::instance())
@@ -78,7 +77,7 @@ Feed::Feed(const QString &feedurl)
         }
     });
 
-    m_entries = new EntriesModel(this);
+    m_entries = new EntriesProxyModel(this);
 }
 
 Feed::~Feed()
