@@ -1,5 +1,5 @@
 /**
- * SPDX-FileCopyrightText: 2020 Tobias Fella <fella@posteo.de>
+ * SPDX-FileCopyrightText: 2020 Tobias Fella <tobias.fella@kde.org>
  * SPDX-FileCopyrightText: 2021-2022 Bart De Vries <bart@mogwai.be>
  *
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
@@ -12,15 +12,12 @@
 #include <QDateTime>
 #include <QDebug>
 #include <QDir>
-#include <QDomElement>
 #include <QFile>
 #include <QFileInfo>
-#include <QMultiMap>
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
-#include <QTextDocumentFragment>
 #include <QTime>
-#include <Syndication/Syndication>
+#include <QTimer>
 
 #include "database.h"
 #include "enclosure.h"
@@ -204,6 +201,24 @@ QNetworkReply *Fetcher::download(const QString &url, const QString &filePath) co
     return reply;
 }
 
+void Fetcher::getRedirectedUrl(const QUrl &url)
+{
+    QNetworkRequest request((QUrl(url)));
+    request.setTransferTimeout(5000); // wait 5 seconds; it will fall back to original url otherwise
+
+    QNetworkReply *reply = head(request);
+
+    connect(reply, &QNetworkReply::finished, this, [this, reply, url]() {
+        qCDebug(kastsFetcher) << "finished looking for redirect; this is the old url and the redirected url:" << url << reply->url();
+
+        QUrl newUrl = reply->url();
+        QTimer::singleShot(0, this, [this, url, newUrl]() {
+            Q_EMIT foundRedirectedUrl(url, newUrl);
+        });
+        reply->deleteLater();
+    });
+}
+
 QNetworkReply *Fetcher::get(QNetworkRequest &request) const
 {
     setHeader(request);
@@ -225,5 +240,5 @@ QNetworkReply *Fetcher::head(QNetworkRequest &request) const
 
 void Fetcher::setHeader(QNetworkRequest &request) const
 {
-    request.setRawHeader(QByteArray("User-Agent"), QByteArray("Kasts/") + QByteArray(KASTS_VERSION_STRING) + QByteArray("; Syndication"));
+    request.setRawHeader(QByteArray("User-Agent"), QByteArray("Kasts/") + QByteArray(KASTS_VERSION_STRING) + QByteArray(" Syndication"));
 }
