@@ -1,22 +1,21 @@
 /**
- * SPDX-FileCopyrightText: 2021 Bart De Vries <bart@mogwai.be>
+ * SPDX-FileCopyrightText: 2021-2023 Bart De Vries <bart@mogwai.be>
  *
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #pragma once
 
-#include <QAbstractListModel>
 #include <QHash>
 #include <QItemSelection>
+#include <QModelIndex>
 #include <QObject>
+#include <QString>
 #include <QVariant>
 
-#include <KFormat>
+#include "models/abstractepisodemodel.h"
 
-#include "audiomanager.h"
-
-class QueueModel : public QAbstractListModel
+class QueueModel : public AbstractEpisodeModel
 {
     Q_OBJECT
 
@@ -29,16 +28,18 @@ public:
         static QueueModel _instance;
         return _instance;
     }
-    explicit QueueModel(QObject * = nullptr);
-    //~QueueModel() override;
+    explicit QueueModel(QObject *parent = nullptr);
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
-    QHash<int, QByteArray> roleNames() const override;
     int rowCount(const QModelIndex &parent) const override;
+
     int timeLeft() const;
     QString formattedTimeLeft() const;
 
     Q_INVOKABLE QItemSelection createSelection(int rowa, int rowb);
 
+public Q_SLOTS:
+    void updateInternalState() override;
+
 Q_SIGNALS:
     void timeLeftChanged();
 };
